@@ -5,14 +5,16 @@ import {
 
 import { IStatusBar } from "@jupyterlab/statusbar";
 
-import registerStatusBarWidget from "../statusBar/registerStatusBarWidget";
+import registerHubWidget from "../statusBar/registerHubWidget";
+import registerUpdateWidget from "../statusBar/registerUpdateWidget";
 
 const frame: JupyterFrontEndPlugin<void> = {
   id: "@tabnine/jupyterlab:frame",
   autoStart: true,
   requires: [IStatusBar],
   activate: async (app: JupyterFrontEnd, statusBar: IStatusBar) => {
-    registerStatusBarWidget(statusBar);
+    registerUpdateWidget(statusBar);
+    registerHubWidget(statusBar);
   },
 };
 
